<?
/**
* Klassenbibliothek fr INI-Dateien
*
* @author Martin Goldmann
*/

require_once('ini.inc.php');

class iniFile
{
	var $strInputFilename;
	var $strOutputFilename;
	
	var $arrSections;
	var $arrEntries;
	var $arrValues;
	
	var $arrIniData;
	
	/**
	* @return iniFile
	* @param unknown $argStrInputFilename
	* @param unknown $argStrOutputFilename
	* @param unknown $argType
	* @desc Konstruktor. Weist die Dateinamen fuer Ein- und Ausgabe zu
	*/
	function iniFile($argStrInputFilename, $argStrOutputFilename, $argType = 'inifile')
	{
		$this->strInputFilename = $argStrInputFilename;
		$this->strOutputFilename = $argStrOutputFilename;
	}

	/**
	* @return Array
	* @param string $node
	* @desc Verwandelt das komplette INI-File in ein 2D-Array.
	* erster Key ist die Section, zweiter Key der Parameter
	*/
	function toArray($node = '')
	{
		$this->arrSections = ReadIniSections($this->strInputFilename);
		
		foreach($this->arrSections as $myStrSection)
		{
			$this->arrEntries[$myStrSection] = ReadIniItems($this->strInputFilename, trim($myStrSection));
		}
		
		foreach($this->arrEntries as $myStrSection => $myArrItems)
		{
			foreach ($myArrItems as $myStrItem)
			{
				$this->arrValues[trim($myStrSection)][trim($myStrItem)] = ReadIniValue($this->strInputFilename, trim($myStrSection), trim($myStrItem));
			}
		}
	return $this->arrValues;
	}
	
	
	/**
	* @return void
	* @param string $argStrSection
	* @param string $argStrItem
	* @param string $argStrValue
	* @desc Einen Eintrag im INI-Array aendern oder hinzufuegen
	*/
	function changeEntry($argStrSection, $argStrItem, $argStrValue)
	{
		$this->arrValues[$argStrSection][$argStrItem] = $argStrValue;
	}
	
	/**
	* @return boolean
	* @desc Fgt eine Parameterzeile ein. Falls Sektion noch nicht existiert, 
	* @desc wird die auch angelegt. 
	* @desc Liefert FALSE zurck, falls Item bereits existiert
	*/
	function addEntry($argStrSection, $argStrItem, $argStrValue)
	{
		// falls notwendig, neue Sektion anlegen
		
		if ($this->getSectionIndex($argStrSection) == -1)
				$this->arrSections[] = $argStrSection;

		// Prfen, ob Item bereits vorhanden
		if (isset($this->arrEntries[$argStrSection][$argStrItem]) || isset($this->arrValues[$argStrSection][$argStrItem]))
			return(false);		

		// Item und Value anhngen
		$this->arrEntries[$argStrSection][] = $argStrItem;
		$this->arrValues[$argStrSection][$argStrItem] = $argStrValue;
		
		return(true);
	}

/**
	* @return boolean
	* @desc Lscht ganze Sektion
	* @desc liefert FALSE, falls Sektion nicht existiert
	*/
	function delSection($argStrSection)
	{
				
		// Prfen, ob Sektion vorhanden ist
		$nIndex = $this->getSectionIndex($argStrSection);
		if ($nIndex==-1)
			return(false);
			
		// Daten leeren
//		array_splice($this->arrSections, $nIndex, 1);
//		array_splice($this->arrEntries, $nIndex, 1);
//		array_splice($this->arrValues, $nIndex, 1);

		unset($this->arrSections[$nIndex]);
		unset($this->arrEntries[$argStrSection]);
		unset($this->arrValues[$argStrSection]);
		
		return(true);
	}
	
	
	/**
	* @return integer
	* @desc gibt Index der genannten Sektion oder -1 zurck, wenn nicht gefunden
	*/
	function getSectionIndex($argStrSection)
	{
		$nRetIndex = -1;
		foreach($this->arrSections as $nKey => $strValue) 
		{
			if (strtolower($strValue)==strtolower($argStrSection))
			{
				$nRetIndex = $nKey;
				break;
			}
		}	

		return($nRetIndex);	
	}

	/**
	* @return array
	* @param string $argStrSection
	* @desc Gibt die Items und Values einer Section zurueck
	*/
	function getSectionData($argStrSection)
	{
		foreach($this->arrValues[$argStrSection] as $myStrItem => $myStrValue)
		{
			$myArrReturn[$myStrItem] = $myStrValue;
		}
		return $myArrReturn;
	}
	
	/**
	* @return string
	* @param string $argStrSection
	* @desc gibt eine Liste aller Sektionen zurck fr Select-Boxen zurck
	* @desc (ohne [global], [printers] und [print$] )
	*/
	function getSharesAsOptionList($argStrCurrentSection)
	{
		$strRetval = '';
		foreach($this->arrSections as $nKey => $strSection)
		{
			// keine wichtigen Sektionen zum Lschen anbieten
			if (strtolower($strSectionLower)  != 'global' && strtolower($strSection) != 'printers' && strtolower($strSection) != 'print$')
			{
				if (strtolower($strSection) == strtolower($argStrCurrentSection))
					$strRetval .= "<option selected>$strSection</option>\n";
				else
					$strRetval .= "<option>$strSection</option>\n";
			}
			
			
		}
		return $strRetval;
	}
	
	
	/**
	* @return void
	* @desc Schreibt die INI-Daten aus dem Array wieder in Datei
	*/
	function writeIniFile($argStrException='')
	{
		$argStrException = strtolower($argStrException);
		foreach ($this->arrValues as $myStrSectionName => $myStrSection)
		{
			// Ausnahme berspringen
			if (!(strtolower($myStrSectionName) == $argStrException))
			{
				
				foreach($myStrSection as $myStrItem => $myStrValue)
				{
					WriteIniValue($this->strOutputFilename, $myStrSectionName, $myStrItem, $myStrValue);
				}
			}
		}
	}
	
	/**
	* @return void
	* @desc Hilfsfunktion, schreibt alle Werte aus $this->arrValues
	*/
	function dumpValues()
	{
		echo '<pre>';
		var_dump($this->arrValues);
		echo "</pre>\n";
	}
}

class iniForm
{
	var $strFormHTML;
	var $lang;
	
	function iniForm($argAction, $argSection, $argMethod='POST', $argArrayToShow)
	{
		global $lang;
		$this->lang = $lang;
		
		$this->arrToShow = $argArrayToShow;		
		$this->strSection = $argSection;
				
		$this->strFormHTML = "<form action='$argAction' method='$argMethod'>\n";
		$this->strFormHTML .= "<input type='hidden' name='section' value='$argSection'>\n";		
		$this->strFormHTML .= "<input type='hidden' name='change' value='true'>\n";
		$this->strFormHTML .= "<table class='iniFormTable'>\n";
	}
	
	function arr2Form($argArrSection)
	{	
		foreach($argArrSection as $myStrItem => $myStrValue)
		{
			// Hilfetext ermitteln
			foreach ($this->arrToShow['param'] as $myArrEntry)
			{
				if ($myStrItem == $myArrEntry['name'])
				{
					$myStrShorthelp = $myArrEntry['shorthelp'];
					$myStrLonghelp = $myArrEntry['longhelp'];
					break;
				}
				//echo $myArrEntry['name'].":".$myArrEntry['shorthelp']."<br>\n";
			}
			
			$this->strFormHTML .= "\t<tr class='iniFormRow'>";
			$this->strFormHTML .= "<td class='iniFormItem'>$myStrItem</td>";
			$this->strFormHTML .= "<td class='iniFormValue'><input type='text' name='".urlencode($myStrItem)."' size='30' value='$myStrValue'></td>";
			$this->strFormHTML .= "<td class='iniFormShorthelp'>$myStrShorthelp</td>";
			$this->strFormHTML .= "<td class='iniFormShorthelp'><a target='helpwindow' href='help.php?n=".urlencode($myStrItem)."&s=".urlencode($myStrShorthelp)."&l=".urlencode($myStrLonghelp)."'>".$this->lang['link_mehr_hilfe']."</a></td>";
			$this->strFormHTML .= "</tr>\n";
			
			// Shorthelp wieder leeren
			$myStrShorthelp = '';
		}
		
		// Feld fr neuen Parameter
		$this->strFormHTML .= "<tr>";
		$this->strFormHTML .= "<td><select size='1' name='new_param'>";
		
		// Array der mglichen Parameter parsen
		// dabei je nach Sektion die dafr erlaubten Parameter verwenden
		foreach ($this->arrToShow['param'] as $myArrEntry)
		{
			if (($this->strSection == 'global') && ($myArrEntry['section'] == 'global'))
			{
					$this->strFormHTML .= "<option value=".urlencode($myArrEntry['name']).">".$myArrEntry['name']."</option>";
			}
			else if (($this->strSection <> 'print$') && ($this->strSection <> 'printers') && ($this->strSection <> 'global') && $this->strSection <> 'homes')
			{
			if ($myArrEntry['section'] == '#share#')
				$this->strFormHTML .= "<option value=".urlencode($myArrEntry['name']).">".$myArrEntry['name']."</option>";
			}
		}
		$this->strFormHTML .= "</select>";
		$this->strFormHTML .= "<td class='iniForm'><input type='text' name='new_value' size='30' value=''></td>";
		$this->strFormHTML .= "</tr>\n";
	}
	
	
	function showForm()
	{
		$this->strFormHTML .= "<tr class='iniFormRow'><td class='iniFormValue' colspan='3' align='center'><input type='submit' value='Eintrge ndern'></td></tr>";
		$this->strFormHTML .= "</table>\n";
		$this->strFormHTML .= "</form>\n";
		return $this->strFormHTML;
	}
}
?>